<!-- Writen by Brian Leonard: http://www.bleonard.com                    -->
<!-- Adapted from MapIt! by Jason Heddings: http://mapit.mozdev.org/     -->
<!-- License: http://creativecommons.org/licenses/by-nc-sa/2.0/          -->

var gDocument;

////////////////////////////////////////////////////////////////////////////////
// Generates a page in a new tab or window

function mapitGenerateDocument(url) {
  var settings = new MapItSettings();
  var genPage = window;

  // check where to send the map
  if (settings.target == "tab") {
    getBrowser().selectedTab = getBrowser().addTab(url);
  } else if (settings.target == "blank") {
    genPage = window.open(url);
  } else {
    // the new page is set to the current window
  }

  return genPage.content.document;
}

////////////////////////////////////////////////////////////////////////////////
// Creates a blank form.

function mapitGenerateForm(method, action) {
  gDocument = mapitGenerateDocument("about:blank");
  var form = gDocument.createElement("form")
  form.setAttribute("method", method);
  form.setAttribute("action", action);
  gDocument.body.appendChild(form);
  return form;
}

////////////////////////////////////////////////////////////////////////////////
// Creates a form input element.

function mapitGenerateInput(name, value) {
  var input = gDocument.createElement("input");
  input.setAttribute("type", "hidden");
  input.setAttribute("name", name);
  input.setAttribute("value", value);
  return input;
}

////////////////////////////////////////////////////////////////////////////////
// Get the form to show directions from ons address to another.
// var method
// 0 - not used
// 1 - ride
// 2 - drive
function mapitGetDirectionsForm(to, from, method) {
	if(method==1)
 		mapitMBTADirections(to, from);
	else
		mapitGoogleDirections(to,from);
}

////////////////////////////////////////////////////////////////////////////////
// Get the form to show a specific map.

function mapitGetShowMapForm(address) {
    mapitGoogle(address);
}

////////////////////////////////////////////////////////////////////////////////
// Submits the form.

function mapitSubmit(form) {
  // This must be done to make generated content render
  const request = new XMLHttpRequest();
  request.open("GET", window.content.document.URL, true);
  request.send("");

  form.submit();
}


function mapitGoogle(address) {
  var form = mapitGenerateForm("get", "http://maps.google.com/");
  if (form != null) {
     form.appendChild(mapitGenerateInput("q", address));
     mapitSubmit(form);
   }
}

function mapitGoogleDirections(to,from) {
  var form = mapitGenerateForm("get", "http://maps.google.com/");
  var query = "";
  if (from != null) {
	  query += "from: " + from;
  }
  if (to != null) {
	  query += " to: " + to;
  }  
  if (form != null) {
    form.appendChild(mapitGenerateInput("q", query));
    mapitSubmit(form);
   }
}



////////////////////////////////////////////////////////////////////////////////
// Create the MBTA form
var gFrom = null;
var gTo = null;

function finishMBTADirections(time,arrdep)
{
  	var form = mapitGenerateForm("post", "http://mbta.com/rider_tools/trip_planner/default.asp");
 	if ((gFrom != null) && (gTo != null)) {
    	form.appendChild(mapitGenerateInput("mode", "A"));

		dateString = "";
		temp = time.getMonth() + 1;
		if(temp < 10)
			dateString += "0";
		dateString += temp + "/";
		temp = time.getDate();
		if(temp < 10)
			dateString += "0";
		dateString += temp + "/";
		temp = time.getFullYear()-2000;
		if(temp < 10)
			dateString += "0";
		dateString += temp;
			
		hourString = "";
		ampmString = "";
		minuteString = "" + time.getMinutes();
		temp = time.getHours();
		if(temp>11)
			ampmString = "PM";
		else
			ampmString = "AM";
		if(temp==0 || temp==12)
			hourString = "12";
		else
		{
			if(temp>12)
				temp -= 12;
//			if(temp < 10)
//				timeString = "0" + temp + timeString;
//			else
				hourString = "" + temp;
		}
		// need to get based on settings
		form.appendChild(mapitGenerateInput("Hour",hourString));
		form.appendChild(mapitGenerateInput("Minute",minuteString));
		form.appendChild(mapitGenerateInput("AMPM",ampmString));
		
		form.appendChild(mapitGenerateInput("sDate", dateString));
		form.appendChild(mapitGenerateInput("Arr", arrdep));

		// <select name="Min" class="ssmalltxt">
		//	 <option value="T" selected>Minimize Time</option>
		//	 <option value="X">Minimize Transfers</option>
		//	 <option value="W">Minimize Walking</option>
		// </select>		
			form.appendChild(mapitGenerateInput("Min", gMapItSettings.tripMinimize));
		//  <select name="Walk" class="ssmalltxt">
		//	  <option value="0.25">1/4 mile</option>
		//	  <option value="0.50" selected>1/2 mile</option>
		//	  <option value="0.75">3/4 mile</option>
		//	  <option value="0.9999">1 mile</option>
		//  </select>	
			form.appendChild(mapitGenerateInput("Walkdist", gMapItSettings.tripWalking));
		// accessible
		// <input type="checkbox" name="Atr" value="Y">
			if(gMapItSettings.tripAccess)
				form.appendChild(mapitGenerateInput("Atr","Y"));
  	}

	  if (gFrom != null) {
		form.appendChild(mapitGenerateInput("sa", gFrom));
	  }
	
	  if (gTo != null) {
		form.appendChild(mapitGenerateInput("ea", gTo));
	  }
	
  	if (form != null) {
     	mapitSubmit(form);
   	}
}

function mapitMBTADirections(to, from) {
	gFrom = from;
	gTo = to;
	if(gMapItSettings.timeVerify)
		window.open("chrome://mbta/content/mbtaTime.xul", "_blank", "chrome,resizable");
	else
	{
		var time = getTravelTime();
		finishMBTADirections(time,gMapItSettings.timeArrDep);
	}
}